Fix Type in GetRandomRegion Function

Robert Shearman rob at codeweavers.com
Fri Aug 20 06:47:04 CDT 2004


Changelog:
- Fix type in GetRandomRegion function.
- Add prototype to header.

-------------- next part --------------
Index: wine/include/wingdi.h
===================================================================
RCS file: /home/wine/wine/include/wingdi.h,v
retrieving revision 1.109
diff -u -p -r1.109 wingdi.h
--- wine/include/wingdi.h	18 Aug 2004 20:58:59 -0000	1.109
+++ wine/include/wingdi.h	20 Aug 2004 11:42:47 -0000
@@ -3412,6 +3412,7 @@ INT       WINAPI GetPath(HDC,LPPOINT,LPB
 COLORREF  WINAPI GetPixel(HDC,INT,INT);
 INT       WINAPI GetPixelFormat(HDC);
 INT       WINAPI GetPolyFillMode(HDC);
+INT       WINAPI GetRandomRgn(HDC,HRGN,INT);
 BOOL      WINAPI GetRasterizerCaps(LPRASTERIZER_STATUS,UINT);
 DWORD     WINAPI GetRegionData(HRGN,DWORD,LPRGNDATA);
 INT       WINAPI GetRelAbs(HDC,DWORD);


More information about the wine-patches mailing list
Index: wine/dlls/gdi/clipping.c
===================================================================
RCS file: /home/wine/wine/dlls/gdi/clipping.c,v
retrieving revision 1.1
diff -u -p -r1.1 clipping.c
--- wine/dlls/gdi/clipping.c	21 Jul 2004 04:07:28 -0000	1.1
+++ wine/dlls/gdi/clipping.c	20 Aug 2004 11:42:46 -0000
@@ -504,18 +504,18 @@ INT16 WINAPI RestoreVisRgn16( HDC16 hdc1
  *
  * NOTES
  *     This function is documented in MSDN online for the case of
- *     dwCode == SYSRGN (4).
+ *     iCode == SYSRGN (4).
  *
  *     For dwCode == 1 it should return the clip region
  *                   2 "    "       "   the meta region
  *                   3 "    "       "   the intersection of the clip with
  *                                      the meta region (== 'Rao' region).
  *
  *     See http://www.codeproject.com/gdi/cliprgnguide.asp
  */
-INT WINAPI GetRandomRgn(HDC hDC, HRGN hRgn, DWORD dwCode)
+INT WINAPI GetRandomRgn(HDC hDC, HRGN hRgn, INT iCode)
 {
-    switch (dwCode)
+    switch (iCode)
     {
     case SYSRGN: /* == 4 */
 	{
@@ -543,7 +543,7 @@ INT WINAPI GetRandomRgn(HDC hDC, HRGN hR
             return GetClipRgn (hDC, hRgn);
 
     default:
-        WARN("Unknown dwCode %ld\n", dwCode);
+        WARN("Unknown iCode %ld\n", iCode);
         return -1;
     }
 
@@ -504,18 +504,18 @@ INT16 WINAPI RestoreVisRgn16( HDC16 hdc1
  *
- *     For dwCode == 1 it should return the clip region
- *                   2 "    "       "   the meta region
- *                   3 "    "       "   the intersection of the clip with
- *                                      the meta region (== 'Rao' region).
+ *     For iCode == 1 it should return the clip region
+ *                  2 "    "       "   the meta region
+ *                  3 "    "       "   the intersection of the clip with
+ *                                     the meta region (== 'Rao' region).
  *
  *     See http://www.codeproject.com/gdi/cliprgnguide.asp